import React, {useCallback, useMemo, useState} from 'react';
import BingoCard from './BingoCard';
import Playlist from './Playlist';
import data from '../music/Playlist-1.json';
import dataNL from '../music/Nederlands.json';
import dataMix from '../music/mixplaylist.json';
import dataMix2 from '../music/mixplaylist2.json';
import QRCodePlaylist from "./QRCodePlaylist.jsx";

const playlists = {
    "Mix": dataMix,
    "Mix 2": dataMix2,
    "Nederlands": dataNL,
    "Engels": data,
};
const views = {
    bingo: "Bingo",
    playlist: "Playlist",
    qrcode: "QR Codes",
};

function clamp(value, min, max) {
    return Math.min(max, Math.max(min, value));
}

function App() {
    const [selectedPlaylist, setSelectedPlaylist] = useState(Object.keys(playlists)[0]);
    const [selectedView, setSelectedView] = useState(Object.keys(views)[0]);

    const [bingoCardsAmount, setBingoCardsAmount] = useState(1);

    const playlist = useMemo(() => {
        return playlists[selectedPlaylist].sort(() => 0.5 - Math.random());
    }, [selectedPlaylist]);

    const onAmountChange = useCallback((event) => {
        const parsed = parseInt(event.target.value, 10);
        setBingoCardsAmount(clamp(parsed, 1, 100));
    }, []);

    return (
        <div className="container my-4">
            <h1 className="text-center text-primary mb-5 d-print-none">
                Muziekbingo
            </h1>
            <div className="d-flex flex-row mb-5 d-print-none">
                <div className="flex-grow-1">
                    <div className="btn-group">
                        {Object.keys(playlists).map((playlistName) => (
                            <button
                                key={playlistName}
                                className={`btn ${selectedPlaylist === playlistName ? 'btn-primary' : 'btn-outline-primary'}`}
                                onClick={() => setSelectedPlaylist(playlistName)}
                            >
                                {playlistName}
                            </button>
                        ))}
                    </div>
                </div>
                <div className="btn-group">
                    {Object.keys(views).map((view) => (
                        <button
                            key={view}
                            className={`btn ${selectedView === view ? 'btn-primary' : 'btn-outline-primary'}`}
                            onClick={() => setSelectedView(view)}
                        >
                            {views[view]}
                        </button>
                    ))}
                </div>
            </div>
            {selectedView === 'bingo' && (
                <React.Fragment>
                    <div className="mb-3 d-print-none">
                        <label className="form-label">
                            Aantal bingokaarten
                        </label>
                        <input
                            type="number"
                            className="form-control"
                            value={bingoCardsAmount}
                            onChange={onAmountChange}
                        />
                    </div>
                    {[...Array(bingoCardsAmount)].map((_, index) => (
                        <div className="mb-5" key={index} style={{breakInside: "avoid"}}>
                            <h1 className="text-center text-primary mb-5 d-none d-print-block">
                                Muziekbingo
                            </h1>
                            <BingoCard songs={playlist}/>
                        </div>
                    ))}
                </React.Fragment>
            )}
            {selectedView === 'playlist' && (
                <Playlist songs={playlist} />
            )}
            {selectedView === 'qrcode' && (
                <QRCodePlaylist songs={playlist} />
            )}
        </div>
    );
}

export default App;
