import React, {useCallback, useEffect, useState} from 'react';

function BingoCard({ songs }) {
    const generateBingoNumbers = useCallback(() => {
        const shuffledSongs = songs.sort(() => 0.5 - Math.random());
        return shuffledSongs.slice(0, 25);
    }, [songs]);

    const [bingoNumbers, setBingoNumbers] = useState(null);

    const refreshBingoCard = useCallback(() => {
        setBingoNumbers(generateBingoNumbers());
    }, [generateBingoNumbers]);

    useEffect(() => {
        setBingoNumbers(generateBingoNumbers());
    }, [generateBingoNumbers]);

    if(!bingoNumbers) {
        return null;
    }

    return (
        <div className="text-center">
            <button className="btn btn-primary mb-3 d-print-none" onClick={refreshBingoCard}>
                Refresh
            </button>
            <div className="d-grid" style={{ gridTemplateColumns: 'repeat(5, 1fr)', gap: '10px' }}>
                {bingoNumbers.map((song, index) => {
                    if(index === 12) {
                        return (
                            <div
                                key={index}
                                className="border-primary rounded py-3 px-2 bg-primary text-white text-center d-flex text-center flex-column align-items-center justify-content-center h-100 text-primary"
                                style={{ aspectRatio: '1/1' }}
                            >
                                <h4 className="m-0">
                                    <b>Muziek Bingo</b>
                                </h4>
                            </div>
                        )
                    }
                    return (
                        <div
                            key={index}
                            className="border rounded py-3 px-2 bg-light text-center d-flex text-center flex-column align-items-center justify-content-center h-100"
                            style={{ aspectRatio: '1/1' }}
                        >
                            <b>{song.title}</b>
                        </div>
                    )
                })}
            </div>
        </div>
    );
}

export default BingoCard;
